@@ -234,6 +234,8 @@ void CallSetting::fromPj(const pjsua_call_setting &prm)
     this->audioCount        = prm.aud_cnt;
     this->videoCount        = prm.vid_cnt;
     this->mediaDir.clear();
+    this->customCallId      = pj2Str(prm.custom_call_id);
+
     /* Since we don't know the size of media_dir array, we populate
      * mediaDir vector up to the element with non-default value.
      */
@@ -260,6 +262,10 @@ pjsua_call_setting CallSetting::toPj() const
     for (mi = 0; mi < this->mediaDir.size(); mi++) {
         setting.media_dir[mi] = (pjmedia_dir)this->mediaDir[mi];
     }
+
+    if( ! this->customCallId.empty()) {
+        setting.custom_call_id = str2Pj(this->customCallId);
+    }
     
     return setting;
 }
